You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by be...@apache.org on 2011/06/05 07:49:49 UTC

svn commit: r1131909 [3/5] - in /incubator/mesos/trunk: ./ frameworks/deploy_jar/ frameworks/hadoop-0.20.0/ frameworks/hadoop-0.20.0/bin/ frameworks/hadoop-0.20.0/src/mapred/org/apache/hadoop/mapred/ frameworks/haproxy+apache/ frameworks/mpi/ framework...

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/master (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/master)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/master?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/master&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/master&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/mesos-daemon (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/nexus-daemon)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/mesos-daemon?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/mesos-daemon&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/nexus-daemon&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/nexus-daemon (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/mesos-daemon Sun Jun  5 05:49:41 2011
@@ -1,10 +1,10 @@
 #!/bin/bash
 
-# Set up NEXUS_HOME in order to find projd
-export NEXUS_HOME=/root/nexus
+# Set up MESOS_HOME in order to find projd
+export MESOS_HOME=/root/mesos
 
-# Set NEXUS_PUBLIC_DNS so slaves can be linked in master web UI
-export NEXUS_PUBLIC_DNS=`wget -q -O - http://instance-data.ec2.internal/latest/meta-data/public-hostname`
+# Set MESOS_PUBLIC_DNS so slaves can be linked in master web UI
+export MESOS_PUBLIC_DNS=`wget -q -O - http://instance-data.ec2.internal/latest/meta-data/public-hostname`
 
 # Set PATH to include Scala
 export PATH=$PATH:/root/scala-2.8.0.RC3/bin
@@ -21,7 +21,7 @@ PROGRAM=$1
 shift
 
 EXTRA_OPTS=""
-if [ "$PROGRAM" == "nexus-slave" ]; then
+if [ "$PROGRAM" == "mesos-slave" ]; then
   # Compute CPU and memory resources on this machine (TODO: Solaris-specific)
   CPUS=`grep processor /proc/cpuinfo | wc -l`
   MEM_KB=`cat /proc/meminfo | grep MemTotal | awk '{print $2}'`
@@ -29,5 +29,5 @@ if [ "$PROGRAM" == "nexus-slave" ]; then
   EXTRA_OPTS="--cpus $CPUS --mem $MEM --isolation process"
 fi
 
-cd $NEXUS_HOME/src
+cd $MESOS_HOME/src
 nohup ./$PROGRAM $EXTRA_OPTS $@ </dev/null >/mnt/$PROGRAM.out 2>&1 &

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/redeploy-mesos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/redeploy-nexus)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/redeploy-mesos?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/redeploy-mesos&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/redeploy-nexus&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/redeploy-nexus (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/redeploy-mesos Sun Jun  5 05:49:41 2011
@@ -1,12 +1,12 @@
 #!/bin/bash
 
-SLAVES=/root/nexus-ec2/slaves
-MASTER=/root/nexus-ec2/master
+SLAVES=/root/mesos-ec2/slaves
+MASTER=/root/mesos-ec2/master
 
 SSH_OPTS="-o StrictHostKeyChecking=no -o ConnectTimeout=2"
 
-echo "RSYNC'ing /root/nexus to slaves..."
+echo "RSYNC'ing /root/mesos to slaves..."
 for slave in `cat $SLAVES`; do
     echo $slave
-    rsync -e "ssh $SSH_OPTS" -az --exclude '*.d' --exclude '*.o' --exclude '*.cpp' --exclude '*.hpp' --exclude '*.pyc' --exclude 'nexus/frameworks/hadoop-0.20.0/logs/*' /root/nexus $slave:/root
+    rsync -e "ssh $SSH_OPTS" -az --exclude '*.d' --exclude '*.o' --exclude '*.cpp' --exclude '*.hpp' --exclude '*.pyc' --exclude 'mesos/frameworks/hadoop-0.20.0/logs/*' /root/mesos $slave:/root
 done

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/runaway-kill (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/runaway-kill)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/runaway-kill?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/runaway-kill&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/runaway-kill&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/runaway-kill (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/runaway-kill Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -8,6 +8,6 @@ SLAVES="`cat slaves`"
 SSH_OPTS="-o StrictHostKeyChecking=no -o ConnectTimeout=2"
 
 for slave in $SLAVES; do
-  echo "Killing ALL processes in ALL Nexus projects on $slave"
-  ssh $SSH_OPTS $slave "for i in 0 1 2 3 4 5 6 7; do for pid in \$(pgrep -J nexus.project.\$i | grep -v \$(pgrep -J nexus.project.\$i projd)); do kill -9 \$pid; done; done"
+  echo "Killing ALL processes in ALL Mesos projects on $slave"
+  ssh $SSH_OPTS $slave "for i in 0 1 2 3 4 5 6 7; do for pid in \$(pgrep -J mesos.project.\$i | grep -v \$(pgrep -J mesos.project.\$i projd)); do kill -9 \$pid; done; done"
 done

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/runaway-killall (from r1131908, incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/runaway-killall)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/runaway-killall?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/runaway-killall&p1=incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/runaway-killall&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/runaway-killall (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/runaway-killall Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -8,6 +8,6 @@ SLAVES="`cat slaves`"
 SSH_OPTS="-o StrictHostKeyChecking=no -o ConnectTimeout=2"
 
 for slave in $SLAVES; do
-  echo "Killing ALL processes in ALL Nexus projects on $slave"
-  ssh $SSH_OPTS $slave "for i in 0 1 2 3 4 5 6 7; do for pid in \$(pgrep -J nexus.project.\$i); do kill -9 \$pid; done; done"
+  echo "Killing ALL processes in ALL Mesos projects on $slave"
+  ssh $SSH_OPTS $slave "for i in 0 1 2 3 4 5 6 7; do for pid in \$(pgrep -J mesos.project.\$i); do kill -9 \$pid; done; done"
 done

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup Sun Jun  5 05:49:41 2011
@@ -4,15 +4,15 @@ DOWNLOAD_METHOD=$2
 BRANCH=$3
 
 # By exporting this git won't ask to accept a key.
-export GIT_SSH=/root/nexus-ec2/ssh-no-keychecking
+export GIT_SSH=/root/mesos-ec2/ssh-no-keychecking
 
-MASTER=/root/nexus-ec2/master
-SLAVES=/root/nexus-ec2/slaves
+MASTER=/root/mesos-ec2/master
+SLAVES=/root/mesos-ec2/slaves
 
-# Scripts that get used for/while running Nexus.
+# Scripts that get used for/while running Mesos.
 SCRIPTS="copy-dir
-         nexus-daemon
-         redeploy-nexus
+         mesos-daemon
+         redeploy-mesos
          setup-apache
          setup-slave              
          setup-torque
@@ -23,9 +23,9 @@ SCRIPTS="copy-dir
          setup-mpi
          ssh-no-keychecking
          start-mos
-         start-nexus
+         start-mesos
          stop-mos
-         stop-nexus
+         stop-mesos
          stop-tasktracker-child"
 
 HADOOP_HOME=/root/hadoop-0.20.2
@@ -42,9 +42,9 @@ if [[ `tty` == "not a tty" ]] ; then
     exit 1
 fi
 
-echo "Setting up Nexus master on `hostname`..."
+echo "Setting up Mesos master on `hostname`..."
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 echo "Setting executable permissions on scripts..."
 for s in $SCRIPTS; do chmod u+x $s; done
@@ -62,17 +62,17 @@ done
 echo "Waiting for commands to finish..."
 wait
 
-echo "RSYNC'ing /root/nexus-ec2 to slaves..."
+echo "RSYNC'ing /root/mesos-ec2 to slaves..."
 for slave in `cat $SLAVES`; do
   echo $slave
-  rsync -e "ssh $SSH_OPTS" -az /root/nexus-ec2 $slave:/root
+  rsync -e "ssh $SSH_OPTS" -az /root/mesos-ec2 $slave:/root
   scp ~/.ssh/id_rsa $slave:.ssh
 done
 
 echo "Setting up slaves..."
 for slave in `cat $SLAVES`; do
   echo $slave
-  ssh -t $SSH_OPTS root@$slave "nexus-ec2/setup-slave"
+  ssh -t $SSH_OPTS root@$slave "mesos-ec2/setup-slave"
 done
 
 echo "Setting up master as slave (i.e. for local)..."
@@ -87,32 +87,32 @@ done
 DOWNLOADED=0
 
 if [[ "$DOWNLOAD_METHOD" == "git" ]] ; then
-  REPOSITORY=git@github.com:nexusproject/nexus.git
-  echo "Checking out Nexus from $REPOSITORY"
+  REPOSITORY=git@github.com:mesosproject/mesos.git
+  echo "Checking out Mesos from $REPOSITORY"
   pushd /root > /dev/null 2>&1
-  rm -rf nexus nexus.tgz
+  rm -rf mesos mesos.tgz
   # Set git SSH command to a script that uses -o StrictHostKeyChecking=no
-  git clone $REPOSITORY nexus
-  pushd nexus 2>&1
+  git clone $REPOSITORY mesos
+  pushd mesos 2>&1
   git checkout -b $BRANCH --track origin/$BRANCH
   popd > /dev/null 2>&1
   popd > /dev/null 2>&1
   DOWNLOADED=1
 elif [[ "$DOWNLOAD_METHOD" == "web" ]] ; then
-  echo "Downloading latest Nexus snapshot from nexus.berkeley.edu"
+  echo "Downloading latest Mesos snapshot from mesos.berkeley.edu"
   pushd /root > /dev/null 2>&1
-  rm -rf nexus nexus.tgz
-  wget http://nexus:nexus@nexus.berkeley.edu/releases/nexus.tgz
-  tar xzf nexus.tgz
+  rm -rf mesos mesos.tgz
+  wget http://mesos:mesos@mesos.berkeley.edu/releases/mesos.tgz
+  tar xzf mesos.tgz
   popd > /dev/null 2>&1
   DOWNLOADED=1
 fi
 
 
-# Build Nexus if we downloaded it
+# Build Mesos if we downloaded it
 if [[ "$DOWNLOADED" == "1" ]] ; then
-  echo "Building Nexus..."
-  pushd /root/nexus > /dev/null 2>&1
+  echo "Building Mesos..."
+  pushd /root/mesos > /dev/null 2>&1
   ./configure.OURS.$OS_NAME
   make clean
   make
@@ -124,25 +124,25 @@ if [[ "$DOWNLOADED" == "1" ]] ; then
     popd > /dev/null 2>&1
   fi
   echo "Building Hadoop framework..."
-  pushd /root/nexus/frameworks/hadoop-0.20.0 > /dev/null 2>&1
+  pushd /root/mesos/frameworks/hadoop-0.20.0 > /dev/null 2>&1
   ant
   ant examples
   popd > /dev/null 2>&1
 fi
 
 echo "Setting up Hadoop framework config files..."
-cp hadoop-framework-conf/* /root/nexus/frameworks/hadoop-0.20.0/conf
+cp hadoop-framework-conf/* /root/mesos/frameworks/hadoop-0.20.0/conf
 
 echo "Setting up haproxy+apache framework config files..."
-cp haproxy+apache/* /root/nexus/frameworks/haproxy+apache
+cp haproxy+apache/* /root/mesos/frameworks/haproxy+apache
 
 echo "Setting up Spark config files..."
 mkdir -p /root/spark/conf
 echo "-Dspark.dfs=hdfs://$HOSTNAME:9000 -Dspark.repl.classdir=/nfs" \
      > /root/spark/conf/java-opts
 
-echo "Redeploying /root/nexus..."
-./redeploy-nexus
+echo "Redeploying /root/mesos..."
+./redeploy-mesos
 
 echo "Setting up NFS..."
 if [ ! -e /mnt/nfs ] ; then
@@ -170,5 +170,5 @@ echo "Starting MapOutputServer(s)..."
 echo "Setting up torque"
 ./setup-torque
 
-echo "Starting Nexus cluster..."
-./start-nexus
+echo "Starting Mesos cluster..."
+./start-mesos

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-apache (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup-apache)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-apache?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-apache&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup-apache&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup-apache (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-apache Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-slave (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup-slave)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-slave?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-slave&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup-slave&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup-slave (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-slave Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-echo "Setting up Nexus slave on `hostname`..."
+echo "Setting up Mesos slave on `hostname`..."
 
 # Mount any ephemeral volumes we might have beyond /mnt
 mkdir -p /mnt2 /mnt3 /mnt4

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-torque (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup-torque)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-torque?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-torque&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup-torque&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/setup-torque (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/setup-torque Sun Jun  5 05:49:41 2011
@@ -1,8 +1,8 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
-SLAVES_FILE="/root/nexus-ec2/slaves"
+SLAVES_FILE="/root/mesos-ec2/slaves"
 MASTER="`cat master`"
 SLAVES="`cat $SLAVES_FILE`"
 
@@ -41,7 +41,7 @@ function setuptorque {
 	qmgr -c "set server scheduler_iteration=$SCHEDULER_ITERATION"
 	#qmgr -c 's s allow_node_submit=true' #other hosts can submit too
 
-	NUM_SLAVES=`cat ~/nexus-ec2/slaves|wc -l`
+	NUM_SLAVES=`cat ~/mesos-ec2/slaves|wc -l`
 	#the server be restarted after this
 	qmgr -c "set queue batch resources_available.nodect=$NUM_SLAVES"
 	#qmgr -c "set server resources_available.nodect=$NUM_SLAVES"
@@ -93,9 +93,9 @@ function installmpi {
 function installmaui {
 	pushd ~
 	#http://www.clusterresources.com/download/maui/maui-3.3.tar.gz
-	rm -rf nexus-maui-3.3.tar
-	wget http://mesos.berkeley.edu/nexus-maui-3.3.tar
-	tar -xf nexus-maui-3.3.tar
+	rm -rf mesos-maui-3.3.tar
+	wget http://mesos.berkeley.edu/mesos-maui-3.3.tar
+	tar -xf mesos-maui-3.3.tar
 	pushd maui-3.3
 	./configure
 	make

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/slaves (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/slaves)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/slaves?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/slaves&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/slaves&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/ssh-no-keychecking (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/ssh-no-keychecking)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/ssh-no-keychecking?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/ssh-no-keychecking&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/ssh-no-keychecking&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/start-mesos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/start-nexus)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/start-mesos?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/start-mesos&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/start-nexus&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/start-nexus (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/start-mesos Sun Jun  5 05:49:41 2011
@@ -1,5 +1,5 @@
 #!/bin/bash
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -7,11 +7,11 @@ SLAVES="`cat slaves`"
 SSH_OPTS="-o StrictHostKeyChecking=no -o ConnectTimeout=2"
 
 echo "Starting master on $MASTER"
-ssh $SSH_OPTS $MASTER "/root/nexus-ec2/nexus-daemon nexus-master -p 1111 </dev/null >/dev/null"
+ssh $SSH_OPTS $MASTER "/root/mesos-ec2/mesos-daemon mesos-master -p 1111 </dev/null >/dev/null"
 
 for slave in $SLAVES; do
   echo "Starting slave on $slave"
-  ssh $SSH_OPTS $slave "/root/nexus-ec2/nexus-daemon nexus-slave 1@$MASTER:1111 </dev/null >/dev/null" &
+  ssh $SSH_OPTS $slave "/root/mesos-ec2/mesos-daemon mesos-slave 1@$MASTER:1111 </dev/null >/dev/null" &
   sleep 0.1
 done
 wait

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/start-mos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/start-mos)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/start-mos?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/start-mos&p1=incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/start-mos&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/start-mos (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/start-mos Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -9,7 +9,7 @@ SSH_OPTS="-o StrictHostKeyChecking=no -o
 
 for slave in $SLAVES; do
   echo "Starting MapOutputServer on $slave"
-  ssh $SSH_OPTS $slave "cd /root/nexus/frameworks/hadoop-0.20.0 ; ulimit -n 2048 ; nohup ./bin/hadoop org.apache.hadoop.mapred.MapOutputServer > /tmp/MapOutputServer.log 2>&1 < /dev/null &" &
+  ssh $SSH_OPTS $slave "cd /root/mesos/frameworks/hadoop-0.20.0 ; ulimit -n 2048 ; nohup ./bin/hadoop org.apache.hadoop.mapred.MapOutputServer > /tmp/MapOutputServer.log 2>&1 < /dev/null &" &
   sleep 0.1
 done
 wait

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-mesos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-nexus)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-mesos?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-mesos&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-nexus&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-nexus (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-mesos Sun Jun  5 05:49:41 2011
@@ -1,5 +1,5 @@
 #!/bin/bash
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -8,10 +8,10 @@ SSH_OPTS="-o StrictHostKeyChecking=no -o
 
 for slave in $SLAVES; do
   echo "Stopping slave on $slave"
-  ssh $SSH_OPTS $slave pkill nexus-slave &
+  ssh $SSH_OPTS $slave pkill mesos-slave &
   sleep 0.1
 done
 wait
 
 echo "Stopping master on $MASTER"
-ssh $SSH_OPTS $MASTER pkill nexus-master
+ssh $SSH_OPTS $MASTER pkill mesos-master

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-mos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-mos)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-mos?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-mos&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-mos&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-mos (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-mos Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"

Copied: incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-tasktracker-child (from r1131908, incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/stop-tasktracker-child)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-tasktracker-child?p2=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-tasktracker-child&p1=incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/stop-tasktracker-child&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/stop-tasktracker-child (original)
+++ incubator/mesos/trunk/src/ec2/deploy.lucid64/root/mesos-ec2/stop-tasktracker-child Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/core-site.xml (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/hadoop-framework-conf/core-site.xml)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/core-site.xml?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/core-site.xml&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/hadoop-framework-conf/core-site.xml&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/hadoop-env.sh (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/hadoop-framework-conf/hadoop-env.sh)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/hadoop-env.sh?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/hadoop-env.sh&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/hadoop-framework-conf/hadoop-env.sh&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/mapred-site.xml (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/hadoop-framework-conf/mapred-site.xml)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/mapred-site.xml?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/mapred-site.xml&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/hadoop-framework-conf/mapred-site.xml&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/hadoop-framework-conf/mapred-site.xml (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/hadoop-framework-conf/mapred-site.xml Sun Jun  5 05:49:41 2011
@@ -6,12 +6,12 @@
 <configuration>
 
   <property>
-    <name>mapred.use.nexus</name>
+    <name>mapred.use.mesos</name>
     <value>true</value>
   </property>
 
   <property>
-    <name>mapred.nexus.master</name>
+    <name>mapred.mesos.master</name>
     <value>1@{{master}}:1111</value>
   </property>
 
@@ -46,7 +46,7 @@
   </property>
 
   <property>
-    <name>mapred.nexus.localitywait</name>
+    <name>mapred.mesos.localitywait</name>
     <value>5000</value>
   </property>
 

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/haproxy+apache/haproxy.config.template (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/haproxy+apache/haproxy.config.template)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/haproxy%2Bapache/haproxy.config.template?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/haproxy%2Bapache/haproxy.config.template&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/haproxy%2Bapache/haproxy.config.template&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/master (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/master)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/master?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/master&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/master&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/mesos-daemon (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/nexus-daemon)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/mesos-daemon?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/mesos-daemon&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/nexus-daemon&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/nexus-daemon (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/mesos-daemon Sun Jun  5 05:49:41 2011
@@ -1,10 +1,10 @@
 #!/bin/bash
 
-# Set up NEXUS_HOME in order to find projd
-export NEXUS_HOME=/root/nexus
+# Set up MESOS_HOME in order to find projd
+export MESOS_HOME=/root/mesos
 
-# Set NEXUS_PUBLIC_DNS so slaves can be linked in master web UI
-export NEXUS_PUBLIC_DNS=`wget -q -O - http://instance-data.ec2.internal/latest/meta-data/public-hostname`
+# Set MESOS_PUBLIC_DNS so slaves can be linked in master web UI
+export MESOS_PUBLIC_DNS=`wget -q -O - http://instance-data.ec2.internal/latest/meta-data/public-hostname`
 
 # Set PATH to include Scala and MPI, since .profile won't be read by SSH
 export PATH=$PATH:/usr/local/bin:/usr/local/scala-2.7.5.final/bin
@@ -21,7 +21,7 @@ PROGRAM=$1
 shift
 
 EXTRA_OPTS=""
-if [ "$PROGRAM" == "nexus-slave" ]; then
+if [ "$PROGRAM" == "mesos-slave" ]; then
   # Compute CPU resources (if not specified).
   if [[ "$*" != *--cpus* ]]; then
     CPUS=`psrinfo | wc -l`
@@ -36,5 +36,5 @@ if [ "$PROGRAM" == "nexus-slave" ]; then
   fi
 fi
 
-cd $NEXUS_HOME/src
+cd $MESOS_HOME/src
 nohup ./$PROGRAM $EXTRA_OPTS $@ </dev/null >/mnt/$PROGRAM.out 2>&1 &

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/redeploy-mesos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/redeploy-nexus)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/redeploy-mesos?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/redeploy-mesos&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/redeploy-nexus&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/redeploy-nexus (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/redeploy-mesos Sun Jun  5 05:49:41 2011
@@ -2,13 +2,13 @@
 
 PATH=/usr/gnu/bin:/usr/bin:/usr/X11/bin:/usr/sbin:/sbin
 
-SLAVES=/root/nexus-ec2/slaves
-MASTER=/root/nexus-ec2/master
+SLAVES=/root/mesos-ec2/slaves
+MASTER=/root/mesos-ec2/master
 
 SSH_OPTS="-o StrictHostKeyChecking=no -o ConnectTimeout=2"
 
-echo "RSYNC'ing /root/nexus to slaves..."
+echo "RSYNC'ing /root/mesos to slaves..."
 for slave in `cat $SLAVES`; do
     echo $slave
-    rsync -e "ssh $SSH_OPTS" -az --exclude '*.d' --exclude '*.o' --exclude '*.cpp' --exclude '*.hpp' --exclude '*.pyc' --exclude 'nexus/frameworks/hadoop-0.20.0/logs/*' /root/nexus $slave:/root
+    rsync -e "ssh $SSH_OPTS" -az --exclude '*.d' --exclude '*.o' --exclude '*.cpp' --exclude '*.hpp' --exclude '*.pyc' --exclude 'mesos/frameworks/hadoop-0.20.0/logs/*' /root/mesos $slave:/root
 done

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/runaway-kill (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/runaway-kill)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/runaway-kill?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/runaway-kill&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/runaway-kill&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/runaway-kill (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/runaway-kill Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -8,6 +8,6 @@ SLAVES="`cat slaves`"
 SSH_OPTS="-o StrictHostKeyChecking=no -o ConnectTimeout=2"
 
 for slave in $SLAVES; do
-  echo "Killing ALL processes in ALL Nexus projects on $slave"
-  ssh $SSH_OPTS $slave "for i in 0 1 2 3 4 5 6 7; do for pid in \$(pgrep -J nexus.project.\$i | grep -v \$(pgrep -J nexus.project.\$i projd)); do kill -9 \$pid; done; done"
+  echo "Killing ALL processes in ALL Mesos projects on $slave"
+  ssh $SSH_OPTS $slave "for i in 0 1 2 3 4 5 6 7; do for pid in \$(pgrep -J mesos.project.\$i | grep -v \$(pgrep -J mesos.project.\$i projd)); do kill -9 \$pid; done; done"
 done

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/runaway-killall (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/runaway-killall)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/runaway-killall?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/runaway-killall&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/runaway-killall&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/runaway-killall (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/runaway-killall Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -8,6 +8,6 @@ SLAVES="`cat slaves`"
 SSH_OPTS="-o StrictHostKeyChecking=no -o ConnectTimeout=2"
 
 for slave in $SLAVES; do
-  echo "Killing ALL processes in ALL Nexus projects on $slave"
-  ssh $SSH_OPTS $slave "for i in 0 1 2 3 4 5 6 7; do for pid in \$(pgrep -J nexus.project.\$i); do kill -9 \$pid; done; done"
+  echo "Killing ALL processes in ALL Mesos projects on $slave"
+  ssh $SSH_OPTS $slave "for i in 0 1 2 3 4 5 6 7; do for pid in \$(pgrep -J mesos.project.\$i); do kill -9 \$pid; done; done"
 done

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup Sun Jun  5 05:49:41 2011
@@ -5,15 +5,15 @@ export PATH=/usr/gnu/bin:/usr/bin:/usr/X
 # Set PATH to include Scala and MPI, since .profile won't be read by SSH.
 export PATH=$PATH:/usr/local/bin:/usr/local/scala-2.7.5.final/bin
 
-MASTER=/root/nexus-ec2/master
-SLAVES=/root/nexus-ec2/slaves
+MASTER=/root/mesos-ec2/master
+SLAVES=/root/mesos-ec2/slaves
 
-# Scripts that get used for/while running Nexus.
+# Scripts that get used for/while running Mesos.
 SCRIPTS="setup-slave              \
-         start-nexus              \
-         stop-nexus               \
-         nexus-daemon             \
-         redeploy-nexus           \
+         start-mesos              \
+         stop-mesos               \
+         mesos-daemon             \
+         redeploy-mesos           \
          start-mos                \
          stop-mos                 \
          setup-apache             \
@@ -30,9 +30,9 @@ if [[ `tty` == "not a tty" ]] ; then
     exit 1
 fi
 
-echo "Setting up Nexus master on `hostname`..."
+echo "Setting up Mesos master on `hostname`..."
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 echo "Setting executable permissions on scripts..."
 for s in $SCRIPTS; do chmod u+x $s; done
@@ -50,16 +50,16 @@ done
 echo "Waiting for commands to finish..."
 wait
 
-echo "RSYNC'ing /root/nexus-ec2 to slaves..."
+echo "RSYNC'ing /root/mesos-ec2 to slaves..."
 for slave in `cat $SLAVES`; do
   echo $slave
-  rsync -e "ssh $SSH_OPTS" -az /root/nexus-ec2 $slave:/root
+  rsync -e "ssh $SSH_OPTS" -az /root/mesos-ec2 $slave:/root
 done
 
 echo "Setting up slaves..."
 for slave in `cat $SLAVES`; do
   echo $slave
-  ssh -t $SSH_OPTS root@$slave "nexus-ec2/setup-slave"
+  ssh -t $SSH_OPTS root@$slave "mesos-ec2/setup-slave"
 done
 
 echo "Setting up master as slave (i.e. for local)..."
@@ -82,10 +82,10 @@ if [[ "$REPLY" == 'Y' || "$REPLY" == 'y'
     while [[ "$REPLY" == '' ]] ; do
 	read -p "Please specify a user name for the repository: "
     done
-    pushd /root/nexus > /dev/null 2>&1
+    pushd /root/mesos > /dev/null 2>&1
     git checkout master
-    git pull ssh://$REPLY@$REPOSITORY/nexus master
-    rm -rf /root/nexus/src/third_party/libprocess
+    git pull ssh://$REPLY@$REPOSITORY/mesos master
+    rm -rf /root/mesos/src/third_party/libprocess
     git config submodule.src/third_party/libprocess.url \
 	ssh://$REPLY@$REPOSITORY/libprocess
     git submodule update --init
@@ -93,23 +93,23 @@ if [[ "$REPLY" == 'Y' || "$REPLY" == 'y'
     make clean
     make
     popd > /dev/null 2>&1
-    pushd /root/nexus/frameworks/spark > /dev/null 2>&1
+    pushd /root/mesos/frameworks/spark > /dev/null 2>&1
     make
     popd > /dev/null 2>&1
-    pushd /root/nexus/frameworks/hadoop-0.20.0 > /dev/null 2>&1
+    pushd /root/mesos/frameworks/hadoop-0.20.0 > /dev/null 2>&1
     ant
     ant examples
     popd > /dev/null 2>&1
 fi
 
 echo "Setting up Hadoop framework config files..."
-cp hadoop-framework-conf/* /root/nexus/frameworks/hadoop-0.20.0/conf
+cp hadoop-framework-conf/* /root/mesos/frameworks/hadoop-0.20.0/conf
 
 echo "Setting up haproxy+apache framework config files..."
-cp haproxy+apache/* /root/nexus/frameworks/haproxy+apache
+cp haproxy+apache/* /root/mesos/frameworks/haproxy+apache
 
-echo "Redeploying /root/nexus..."
-./redeploy-nexus
+echo "Redeploying /root/mesos..."
+./redeploy-mesos
 
 echo "Formatting HDFS namenode..."
 $HADOOP_HOME/bin/hadoop namenode -format
@@ -120,5 +120,5 @@ $HADOOP_HOME/bin/start-dfs.sh
 echo "Starting MapOutputServer(s)..."
 ./start-mos
 
-echo "Starting Nexus cluster..."
-./start-nexus
+echo "Starting Mesos cluster..."
+./start-mesos

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup-apache (from r1131908, incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/setup-apache)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup-apache?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup-apache&p1=incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/setup-apache&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.karmic64/root/nexus-ec2/setup-apache (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup-apache Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup-slave (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup-slave)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup-slave?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup-slave&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup-slave&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/setup-slave (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/setup-slave Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-echo "Setting up Nexus slave on `hostname`..."
+echo "Setting up Mesos slave on `hostname`..."
 
 #echo "Configuring swap space..."
 #if [ ! -e /dev/zvol/dsk/mnt/swap ]; then
@@ -14,15 +14,15 @@ useradd andyk
 useradd benh
 useradd matei
 
-echo "Adding Nexus projects..."
-projadd -U alig,andyk,benh,matei nexus.project.0
-projadd -U alig,andyk,benh,matei nexus.project.1
-projadd -U alig,andyk,benh,matei nexus.project.2
-projadd -U alig,andyk,benh,matei nexus.project.3
-projadd -U alig,andyk,benh,matei nexus.project.4
-projadd -U alig,andyk,benh,matei nexus.project.5
-projadd -U alig,andyk,benh,matei nexus.project.6
-projadd -U alig,andyk,benh,matei nexus.project.7
+echo "Adding Mesos projects..."
+projadd -U alig,andyk,benh,matei mesos.project.0
+projadd -U alig,andyk,benh,matei mesos.project.1
+projadd -U alig,andyk,benh,matei mesos.project.2
+projadd -U alig,andyk,benh,matei mesos.project.3
+projadd -U alig,andyk,benh,matei mesos.project.4
+projadd -U alig,andyk,benh,matei mesos.project.5
+projadd -U alig,andyk,benh,matei mesos.project.6
+projadd -U alig,andyk,benh,matei mesos.project.7
 
 echo "Setting up rcapd intervals..."
 rcapadm -c 90 -i scan=1,sample=1,config=1

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/slaves (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/slaves)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/slaves?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/slaves&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/slaves&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/start-mesos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/start-nexus)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/start-mesos?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/start-mesos&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/start-nexus&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/start-nexus (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/start-mesos Sun Jun  5 05:49:41 2011
@@ -1,5 +1,5 @@
 #!/bin/bash
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -7,7 +7,7 @@ SLAVES="`cat slaves`"
 SSH_OPTS="-o StrictHostKeyChecking=no -o ConnectTimeout=2"
 
 echo "Starting master on $MASTER"
-ssh $SSH_OPTS $MASTER "/root/nexus-ec2/nexus-daemon nexus-master -p 1111 </dev/null >/dev/null"
+ssh $SSH_OPTS $MASTER "/root/mesos-ec2/mesos-daemon mesos-master -p 1111 </dev/null >/dev/null"
 
 COUNT=''
 CPUS=''
@@ -38,7 +38,7 @@ fi
 
 for slave in $SLAVES; do
   echo "Starting $COUNT slave(s) on $slave"
-  ssh $SSH_OPTS $slave "for ((i = 0; i < $COUNT; i++)); do /root/nexus-ec2/nexus-daemon nexus-slave 1@$MASTER:1111 $CPUS $MEM; done </dev/null >/dev/null" &
+  ssh $SSH_OPTS $slave "for ((i = 0; i < $COUNT; i++)); do /root/mesos-ec2/mesos-daemon mesos-slave 1@$MASTER:1111 $CPUS $MEM; done </dev/null >/dev/null" &
   sleep 0.1
 done
 wait

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/start-mos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/start-mos)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/start-mos?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/start-mos&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/start-mos&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/start-mos (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/start-mos Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -9,7 +9,7 @@ SSH_OPTS="-o StrictHostKeyChecking=no -o
 
 for slave in $SLAVES; do
   echo "Starting MapOutputServer on $slave"
-  ssh $SSH_OPTS $slave "cd /root/nexus/frameworks/hadoop-0.20.0 ; ulimit -n 2048 ; export LD_PRELOAD_32=/usr/lib/extendedFILE.so.1 ; nohup ./bin/hadoop org.apache.hadoop.mapred.MapOutputServer > /tmp/MapOutputServer.log 2>&1 < /dev/null &" &
+  ssh $SSH_OPTS $slave "cd /root/mesos/frameworks/hadoop-0.20.0 ; ulimit -n 2048 ; export LD_PRELOAD_32=/usr/lib/extendedFILE.so.1 ; nohup ./bin/hadoop org.apache.hadoop.mapred.MapOutputServer > /tmp/MapOutputServer.log 2>&1 < /dev/null &" &
   sleep 0.1
 done
 wait

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-mesos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/stop-nexus)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-mesos?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-mesos&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/stop-nexus&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/stop-nexus (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-mesos Sun Jun  5 05:49:41 2011
@@ -1,5 +1,5 @@
 #!/bin/bash
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"
@@ -8,10 +8,10 @@ SSH_OPTS="-o StrictHostKeyChecking=no -o
 
 for slave in $SLAVES; do
   echo "Stopping slave(s) on $slave"
-  ssh $SSH_OPTS $slave pkill nexus-slave &
+  ssh $SSH_OPTS $slave pkill mesos-slave &
   sleep 0.1
 done
 wait
 
 echo "Stopping master on $MASTER"
-ssh $SSH_OPTS $MASTER pkill nexus-master
+ssh $SSH_OPTS $MASTER pkill mesos-master

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-mos (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/stop-mos)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-mos?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-mos&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/stop-mos&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/stop-mos (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-mos Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-tasktracker-child (from r1131908, incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-tasktracker-child)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-tasktracker-child?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-tasktracker-child&p1=incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-tasktracker-child&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/deploy.lucid64/root/nexus-ec2/stop-tasktracker-child (original)
+++ incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/stop-tasktracker-child Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-cd /root/nexus-ec2
+cd /root/mesos-ec2
 
 MASTER="`cat master`"
 SLAVES="`cat slaves`"

Copied: incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/zoo (from r1131908, incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/zoo)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/zoo?p2=incubator/mesos/trunk/src/ec2/deploy.solaris/root/mesos-ec2/zoo&p1=incubator/mesos/trunk/src/ec2/deploy.solaris/root/nexus-ec2/zoo&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
    (empty)

Modified: incubator/mesos/trunk/src/ec2/launch-torque-fw.sh
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/launch-torque-fw.sh?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/launch-torque-fw.sh (original)
+++ incubator/mesos/trunk/src/ec2/launch-torque-fw.sh Sun Jun  5 05:49:41 2011
@@ -3,7 +3,7 @@
 NUM_SLAVES=$1
 
 if [ $NUM_SLAVES ]; then
-  ./nexus-ec2 -k andyk -i ~/.ec2/andyk.pem -s $NUM_SLAVES launch nexus-torque-fw -d git -b torque
+  ./mesos-ec2 -k andyk -i ~/.ec2/andyk.pem -s $NUM_SLAVES launch mesos-torque-fw -d git -b torque
 else
   echo "error, specify num nodes"
   exit

Added: incubator/mesos/trunk/src/ec2/mesos-ec2
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/mesos-ec2?rev=1131909&view=auto
==============================================================================
--- incubator/mesos/trunk/src/ec2/mesos-ec2 (added)
+++ incubator/mesos/trunk/src/ec2/mesos-ec2 Sun Jun  5 05:49:41 2011
@@ -0,0 +1,3 @@
+#!/bin/sh
+cd "`dirname $0`"
+PYTHONPATH="$PYTHONPATH:../third_party/boto-1.8d" python ./mesos_ec2.py $@

Propchange: incubator/mesos/trunk/src/ec2/mesos-ec2
------------------------------------------------------------------------------
    svn:executable = *

Copied: incubator/mesos/trunk/src/ec2/mesos_ec2.py (from r1131908, incubator/mesos/trunk/src/ec2/nexus_ec2.py)
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/ec2/mesos_ec2.py?p2=incubator/mesos/trunk/src/ec2/mesos_ec2.py&p1=incubator/mesos/trunk/src/ec2/nexus_ec2.py&r1=1131908&r2=1131909&rev=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/ec2/nexus_ec2.py (original)
+++ incubator/mesos/trunk/src/ec2/mesos_ec2.py Sun Jun  5 05:49:41 2011
@@ -15,7 +15,7 @@ from tempfile import NamedTemporaryFile
 
 
 def parse_args():
-  parser = OptionParser(usage="nexus-ec2 [options] <action> <cluster_name>"
+  parser = OptionParser(usage="mesos-ec2 [options] <action> <cluster_name>"
       + "\n\n<action> can be: launch, shutdown, login, get-master",
       add_help_option=False)
   parser.add_option("-h", "--help", action="help",
@@ -39,7 +39,7 @@ def parse_args():
   parser.add_option("-d", "--download", metavar="SOURCE", default="none",
       help="Where to download latest code from: set to 'git' to check out " +
            "from git, 'web' for latest snapshot .tgz, or 'none' to use " +
-           "the build of Nexus on the AMI (default)")
+           "the build of Mesos on the AMI (default)")
   parser.add_option("-b", "--branch", default="master",
       help="if using git, which branch to check out. default is 'master'")
   parser.add_option("-D", metavar="[ADDRESS:]PORT", dest="proxy_port", 
@@ -50,7 +50,7 @@ def parse_args():
            "(for debugging)")
   parser.add_option("-f", "--ft", default="1", 
       help="Number of masters to run. Default is 1. " + 
-           "Greater values cause Nexus to run in FT mode with ZooKeeper")
+           "Greater values cause Mesos to run in FT mode with ZooKeeper")
   (opts, args) = parser.parse_args()
   opts.ft = int(opts.ft)
   if len(args) != 2:
@@ -79,7 +79,7 @@ def get_or_make_group(conn, name):
     return group[0]
   else:
     print "Creating security group " + name
-    return conn.create_security_group(name, "Nexus EC2 group")
+    return conn.create_security_group(name, "Mesos EC2 group")
 
 
 def wait_for_instances(conn, reservation):
@@ -276,8 +276,8 @@ def main():
     ssh(master, opts, 'mkdir -p /root/.ssh')
     scp(master, opts, opts.identity_file, '/root/.ssh/id_rsa')
     print "Running setup on master..."
-    ssh(master, opts, "chmod u+x nexus-ec2/setup")
-    ssh(master, opts, "nexus-ec2/setup %s %s %s" % (opts.os, opts.download, opts.branch))
+    ssh(master, opts, "chmod u+x mesos-ec2/setup")
+    ssh(master, opts, "mesos-ec2/setup %s %s %s" % (opts.os, opts.download, opts.branch))
     print "Done!"
   elif action == "shutdown":
     response = raw_input("Are you sure you want to shut down the cluster " +

Modified: incubator/mesos/trunk/src/factory.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/factory.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/factory.hpp (original)
+++ incubator/mesos/trunk/src/factory.hpp Sun Jun  5 05:49:41 2011
@@ -32,7 +32,7 @@
 
 
 #define DECLARE_FACTORY(T, P) \
-  class T##Factory : public ::nexus::internal::factory::Factory<T, P> { \
+  class T##Factory : public ::mesos::internal::factory::Factory<T, P> { \
     T##Factory(); \
     static T##Factory *instance; \
     static void initialize(); \
@@ -59,7 +59,7 @@
 
 // Helper classes for the factory macros
 
-namespace nexus { namespace internal { namespace factory {
+namespace mesos { namespace internal { namespace factory {
 
 template<typename T, typename P> class Creator {
 public:

Modified: incubator/mesos/trunk/src/gc.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/gc.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/gc.cpp (original)
+++ incubator/mesos/trunk/src/gc.cpp Sun Jun  5 05:49:41 2011
@@ -2,7 +2,7 @@
 
 namespace process { namespace record {
 
-enum { SHUTDOWN = NEXUS_MESSAGES, CLEANUP };
+enum { SHUTDOWN = MESOS_MESSAGES, CLEANUP };
 
 RECORD(SHUTDOWN, ());
 RECORD(CLEANUP, (SchedulerProcess *));

Modified: incubator/mesos/trunk/src/isolation_module.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/isolation_module.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/isolation_module.cpp (original)
+++ incubator/mesos/trunk/src/isolation_module.cpp Sun Jun  5 05:49:41 2011
@@ -8,7 +8,7 @@
 
 using std::string;
 
-using namespace nexus::internal::slave;
+using namespace mesos::internal::slave;
 
 
 IsolationModule * IsolationModule::create(const string &type)

Modified: incubator/mesos/trunk/src/isolation_module.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/isolation_module.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/isolation_module.hpp (original)
+++ incubator/mesos/trunk/src/isolation_module.hpp Sun Jun  5 05:49:41 2011
@@ -4,7 +4,7 @@
 #include <string>
 
 
-namespace nexus { namespace internal { namespace slave {
+namespace mesos { namespace internal { namespace slave {
 
 class Framework;
 class Slave;

Modified: incubator/mesos/trunk/src/isolation_module_factory.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/isolation_module_factory.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/isolation_module_factory.cpp (original)
+++ incubator/mesos/trunk/src/isolation_module_factory.cpp Sun Jun  5 05:49:41 2011
@@ -6,7 +6,7 @@
 #include "lxc_isolation_module.hpp"
 #endif
 
-using namespace nexus::internal::slave;
+using namespace mesos::internal::slave;
 
 
 DEFINE_FACTORY(IsolationModule, Slave *)

Modified: incubator/mesos/trunk/src/isolation_module_factory.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/isolation_module_factory.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/isolation_module_factory.hpp (original)
+++ incubator/mesos/trunk/src/isolation_module_factory.hpp Sun Jun  5 05:49:41 2011
@@ -4,7 +4,7 @@
 #include "isolation_module.hpp"
 #include "factory.hpp"
 
-namespace nexus { namespace internal { namespace slave {
+namespace mesos { namespace internal { namespace slave {
 
 DECLARE_FACTORY(IsolationModule, Slave *);
 

Modified: incubator/mesos/trunk/src/launcher.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/launcher.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/launcher.hpp (original)
+++ incubator/mesos/trunk/src/launcher.hpp Sun Jun  5 05:49:41 2011
@@ -4,11 +4,11 @@
 #include <string>
 #include <vector>
 
-#include "nexus.hpp"
+#include "mesos.hpp"
 
 #include "fatal.hpp"
 
-namespace nexus { namespace internal { namespace launcher {
+namespace mesos { namespace internal { namespace launcher {
 
 using std::string;
 using std::vector;

Modified: incubator/mesos/trunk/src/launcher_main.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/launcher_main.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/launcher_main.cpp (original)
+++ incubator/mesos/trunk/src/launcher_main.cpp Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #include "launcher.hpp"
 
-#include "nexus.hpp"
+#include "mesos.hpp"
 
 #include <boost/lexical_cast.hpp>
 
@@ -8,8 +8,8 @@ using std::string;
 
 using boost::lexical_cast;
 
-using namespace nexus;
-using namespace nexus::internal::launcher;
+using namespace mesos;
+using namespace mesos::internal::launcher;
 
 
 const char * getenvOrFail(const char *variable) {
@@ -23,12 +23,12 @@ const char * getenvOrFail(const char *va
 int main(int argc, char **argv)
 {
   string_map params;   // Empty map
-  ExecutorLauncher(lexical_cast<FrameworkID>(getenvOrFail("NEXUS_FRAMEWORK_ID")),
-                   getenvOrFail("NEXUS_EXECUTOR_URI"),
-                   getenvOrFail("NEXUS_USER"),
-                   getenvOrFail("NEXUS_WORK_DIRECTORY"),
-                   getenvOrFail("NEXUS_SLAVE_PID"),
-                   lexical_cast<bool>(getenvOrFail("NEXUS_REDIRECT_IO")),
+  ExecutorLauncher(lexical_cast<FrameworkID>(getenvOrFail("MESOS_FRAMEWORK_ID")),
+                   getenvOrFail("MESOS_EXECUTOR_URI"),
+                   getenvOrFail("MESOS_USER"),
+                   getenvOrFail("MESOS_WORK_DIRECTORY"),
+                   getenvOrFail("MESOS_SLAVE_PID"),
+                   lexical_cast<bool>(getenvOrFail("MESOS_REDIRECT_IO")),
                    params).run();
   return 0;
 }

Modified: incubator/mesos/trunk/src/local.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/local.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/local.cpp (original)
+++ incubator/mesos/trunk/src/local.cpp Sun Jun  5 05:49:41 2011
@@ -5,15 +5,15 @@
 
 #include "configurator.hpp"
 #include "logging.hpp"
-#include "nexus_local.hpp"
+#include "mesos_local.hpp"
 
 using std::cerr;
 using std::endl;
 using std::string;
 
-using namespace nexus::internal;
-using nexus::internal::master::Master;
-using nexus::internal::slave::Slave;
+using namespace mesos::internal;
+using mesos::internal::master::Master;
+using mesos::internal::slave::Slave;
 
 
 void usage(const char* programName, const Configurator& conf)

Modified: incubator/mesos/trunk/src/lock.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/lock.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/lock.cpp (original)
+++ incubator/mesos/trunk/src/lock.cpp Sun Jun  5 05:49:41 2011
@@ -1,6 +1,6 @@
 #include "lock.hpp"
 
-using namespace nexus::internal;
+using namespace mesos::internal;
 
 
 Lock::Lock(pthread_mutex_t* _mutex): mutex(_mutex)

Modified: incubator/mesos/trunk/src/lock.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/lock.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/lock.hpp (original)
+++ incubator/mesos/trunk/src/lock.hpp Sun Jun  5 05:49:41 2011
@@ -3,7 +3,7 @@
 
 #include <pthread.h>
 
-namespace nexus { namespace internal {
+namespace mesos { namespace internal {
 
 /**
  * RAII class for locking pthread_mutexes.
@@ -17,6 +17,6 @@ public:
   ~Lock();
 };
 
-}} /* namespace nexus { namespace internal { */
+}} /* namespace mesos { namespace internal { */
 
 #endif /* LOCK_HPP */

Modified: incubator/mesos/trunk/src/logging.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/logging.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/logging.cpp (original)
+++ incubator/mesos/trunk/src/logging.cpp Sun Jun  5 05:49:41 2011
@@ -3,7 +3,7 @@
 #include <glog/logging.h>
 
 using std::string;
-using namespace nexus::internal;
+using namespace mesos::internal;
 
 namespace {
 const string DEFAULT_LOG_DIR = "/tmp";

Modified: incubator/mesos/trunk/src/logging.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/logging.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/logging.hpp (original)
+++ incubator/mesos/trunk/src/logging.hpp Sun Jun  5 05:49:41 2011
@@ -3,7 +3,7 @@
 
 #include "configurator.hpp"
 
-namespace nexus { namespace internal {
+namespace mesos { namespace internal {
 
 using std::string;
 
@@ -18,6 +18,6 @@ public:
   static bool isQuiet(const Params& conf);
 };
 
-}} /* namespace nexus::internal */
+}} /* namespace mesos::internal */
 
 #endif

Modified: incubator/mesos/trunk/src/lr.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/lr.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/lr.cpp (original)
+++ incubator/mesos/trunk/src/lr.cpp Sun Jun  5 05:49:41 2011
@@ -4,7 +4,7 @@
 #include <iostream>
 #include <iomanip>
 #include <pthread.h>
-#include <nexus_sched.h>
+#include <mesos_sched.h>
 #include <boost/unordered_map.hpp>
 #include "lr.hpp"
 
@@ -12,8 +12,8 @@ using namespace std;
 using namespace boost;
 
 
-string nexusHost;
-unsigned short nexusPort;
+string mesosHost;
+unsigned short mesosPort;
 int numIters;
 int numTasks;
 double w[D];
@@ -23,7 +23,7 @@ volatile bool tasksDone = false;
 int numTasksStarted;
 int numTasksFinished;
 
-nexus_handle nexusHandle;
+mesos_handle mesosHandle;
 pthread_t schedulerThread;
 pthread_mutex_t mutex;
 pthread_cond_t tasksDoneCond;
@@ -61,8 +61,8 @@ int main(int argc, char **argv)
     return 1;
   }
   
-  nexusHost = argv[1];
-  nexusPort = atoi(argv[2]);
+  mesosHost = argv[1];
+  mesosPort = atoi(argv[2]);
   numIters = atoi(argv[3]);
   numTasks = atoi(argv[4]);
   
@@ -109,23 +109,23 @@ int main(int argc, char **argv)
     cout << endl << endl;
   }
   
-  nexus_close_scheduler(nexusHandle);
+  mesos_close_scheduler(mesosHandle);
   exit(0);
 }
 
 
-// Nexus callbacks
-void registerStarted(nexus_scheduler *sched);
-void registered(nexus_scheduler *sched, framework_id fid);
-void slot_offer(nexus_scheduler *sched, slot_offer_id oid, nexus_slot *slot);
-void slot_offer_rescinded(nexus_scheduler *sched, slot_offer_id oid);
-void status_update(nexus_scheduler *sched, nexus_task_status *status);
-void framework_message(nexus_scheduler *sched, nexus_framework_message *msg);
-void slave_lost(nexus_scheduler *sched, slave_id sid);
-void error(nexus_scheduler *sched, int code, const char *message);
+// Mesos callbacks
+void registerStarted(mesos_scheduler *sched);
+void registered(mesos_scheduler *sched, framework_id fid);
+void slot_offer(mesos_scheduler *sched, slot_offer_id oid, mesos_slot *slot);
+void slot_offer_rescinded(mesos_scheduler *sched, slot_offer_id oid);
+void status_update(mesos_scheduler *sched, mesos_task_status *status);
+void framework_message(mesos_scheduler *sched, mesos_framework_message *msg);
+void slave_lost(mesos_scheduler *sched, slave_id sid);
+void error(mesos_scheduler *sched, int code, const char *message);
 
-// Nexus scheduler
-nexus_scheduler scheduler = {
+// Mesos scheduler
+mesos_scheduler scheduler = {
   "LR framework",
   "lr_exec",
   registerStarted,
@@ -149,38 +149,38 @@ task_id nextTaskId = 0;
 
 void * runScheduler(void *)
 {
-  nexus_run_scheduler(nexusHost.c_str(), nexusPort, &scheduler, &nexusHandle);
+  mesos_run_scheduler(mesosHost.c_str(), mesosPort, &scheduler, &mesosHandle);
 }
 
-void registerStarted(nexus_scheduler *sched)
+void registerStarted(mesos_scheduler *sched)
 {
   cout << "Started registering" << endl;
 }
 
-void registered(nexus_scheduler *sched, framework_id fid)
+void registered(mesos_scheduler *sched, framework_id fid)
 {
-  cout << "Registered with Nexus, framework ID = " << fid << endl;
+  cout << "Registered with Mesos, framework ID = " << fid << endl;
 }
 
-void slot_offer(nexus_scheduler *sched, slot_offer_id oid, nexus_slot *slot)
+void slot_offer(mesos_scheduler *sched, slot_offer_id oid, mesos_slot *slot)
 {
   cout << "Got slot offer for slave " << slot->sid << endl;
   if (tasksAvailable && numTasksStarted < numTasks) {
-    nexus_task_desc task;
+    mesos_task_desc task;
     task.tid = nextTaskId++;
     indexOfTask[task.tid] = numTasksStarted++;
     task.name = 0;
     task.arg = (void*) w;
     task.arg_len = sizeof(w);
-    nexus_accept_slot_offer(nexusHandle, oid, &task);
+    mesos_accept_slot_offer(mesosHandle, oid, &task);
     cout << "Scheduled task " << indexOfTask[task.tid] 
          << " as TID " << task.tid << endl;
   } else {
-    nexus_refuse_slot_offer(nexusHandle, oid);
+    mesos_refuse_slot_offer(mesosHandle, oid);
   }
 }
 
-void status_update(nexus_scheduler *sched, nexus_task_status *status)
+void status_update(mesos_scheduler *sched, mesos_task_status *status)
 {
   if (status->state == TASK_FINISHED) {
     cout << "Task ID " << status->tid << " finished" << endl;
@@ -202,14 +202,14 @@ void status_update(nexus_scheduler *sche
   }
 }
 
-void error(nexus_scheduler *sched, int code, const char *message)
+void error(mesos_scheduler *sched, int code, const char *message)
 {
-  cout << "Error from Nexus: " << message << endl;
+  cout << "Error from Mesos: " << message << endl;
   exit(code);
 }
 
-void slot_offer_rescinded(nexus_scheduler *sched, slot_offer_id oid) {}
+void slot_offer_rescinded(mesos_scheduler *sched, slot_offer_id oid) {}
 
-void framework_message(nexus_scheduler *sched, nexus_framework_message *msg) {}
+void framework_message(mesos_scheduler *sched, mesos_framework_message *msg) {}
 
-void slave_lost(nexus_scheduler *sched, slave_id sid) {}
+void slave_lost(mesos_scheduler *sched, slave_id sid) {}

Modified: incubator/mesos/trunk/src/lr_exec.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/lr_exec.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/lr_exec.cpp (original)
+++ incubator/mesos/trunk/src/lr_exec.cpp Sun Jun  5 05:49:41 2011
@@ -5,7 +5,7 @@
 #include <vector>
 #include <iostream>
 #include <fstream>
-#include <nexus_exec.h>
+#include <mesos_exec.h>
 #include <boost/unordered_map.hpp>
 #include "lr.hpp"
 
@@ -78,12 +78,12 @@ void * runTask(void *arg) {
   }
   
   // Return the result in a task status
-  nexus_task_status status;
+  mesos_task_status status;
   status.tid = task->tid;
   status.state = TASK_FINISHED;
   status.data = (void*) result;
   status.data_len = D * sizeof(double);
-  nexus_send_status_update(&status);
+  mesos_send_status_update(&status);
   
   // Clean up the task (since we own it) and exit the worker thread
   delete task;
@@ -93,7 +93,7 @@ void * runTask(void *arg) {
 
 extern "C" {
 
-bool lr_exec_initialize(nexus_exec_args *args)
+bool lr_exec_initialize(mesos_exec_args *args)
 {
   cout << "lr_exec_initialize" << endl;
   pthread_mutex_init(&mutex, 0);
@@ -101,7 +101,7 @@ bool lr_exec_initialize(nexus_exec_args 
 }
 
 
-bool lr_exec_start_task(struct nexus_task_desc *task_desc)
+bool lr_exec_start_task(struct mesos_task_desc *task_desc)
 {
   cout << "lr_exec_start_task" << endl;
   
@@ -126,7 +126,7 @@ bool lr_exec_kill_task(task_id tid)
 }
 
 
-bool lr_exec_framework_message(struct nexus_framework_message *message)
+bool lr_exec_framework_message(struct mesos_framework_message *message)
 {
   return true;
 }

Modified: incubator/mesos/trunk/src/lxc_isolation_module.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/lxc_isolation_module.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/lxc_isolation_module.cpp (original)
+++ incubator/mesos/trunk/src/lxc_isolation_module.cpp Sun Jun  5 05:49:41 2011
@@ -1,5 +1,8 @@
 #include "lxc_isolation_module.hpp"
 
+#include <stdlib.h>
+#include <unistd.h>
+
 #include <algorithm>
 
 #include "foreach.hpp"
@@ -20,9 +23,17 @@ using boost::lexical_cast;
 using boost::unordered_map;
 using boost::unordered_set;
 
-using namespace nexus;
-using namespace nexus::internal;
-using namespace nexus::internal::slave;
+using namespace mesos;
+using namespace mesos::internal;
+using namespace mesos::internal::slave;
+
+namespace {
+
+const int32_t CPU_SHARES_PER_CPU = 1024;
+const int32_t MIN_CPU_SHARES = 10;
+const int64_t MIN_RSS = 128 * Megabyte;
+
+}
 
 
 LxcIsolationModule::LxcIsolationModule()
@@ -46,6 +57,19 @@ LxcIsolationModule::~LxcIsolationModule(
 void LxcIsolationModule::initialize(Slave *slave)
 {
   this->slave = slave;
+  
+  // Run a basic check to see whether Linux Container tools are available
+  if (system("lxc-version > /dev/null") != 0) {
+    LOG(FATAL) << "Could not run lxc-version; make sure Linux Container "
+                << "tools are installed";
+  }
+
+  // Check that we are root (it might also be possible to create Linux
+  // containers without being root, but we can support that later)
+  if (getuid() != 0) {
+    LOG(FATAL) << "LXC isolation module requires slave to run as root";
+  }
+
   reaper = new Reaper(this);
   Process::spawn(reaper);
   initialized = true;
@@ -53,18 +77,21 @@ void LxcIsolationModule::initialize(Slav
 
 
 
-void LxcIsolationModule::frameworkAdded(Framework* framework)
+void LxcIsolationModule::frameworkAdded(Framework* fw)
 {
-  lxcExecutePid[framework->id] = -1;
-  container[framework->id] = "";
-  framework->executorStatus = "No executor running";
+  infos[fw->id] = new FrameworkInfo();
+  infos[fw->id]->lxcExecutePid = -1;
+  infos[fw->id]->container = "";
+  fw->executorStatus = "No executor running";
 }
 
 
-void LxcIsolationModule::frameworkRemoved(Framework *framework)
+void LxcIsolationModule::frameworkRemoved(Framework* fw)
 {
-  lxcExecutePid.erase(framework->id);
-  container.erase(framework->id);
+  if (infos.find(fw->id) != infos.end()) {
+    delete infos[fw->id];
+    infos.erase(fw->id);
+  }
 }
 
 
@@ -75,23 +102,23 @@ void LxcIsolationModule::startExecutor(F
 
   LOG(INFO) << "Starting executor for framework " << fw->id << ": "
             << fw->executorInfo.uri;
-  CHECK(lxcExecutePid[fw->id] == -1 && container[fw->id] == "");
+  CHECK(infos[fw->id]->lxcExecutePid == -1 && infos[fw->id]->container == "");
 
-  // Get location of Nexus install in order to find nexus-launcher.
-  const char *nexusHome = getenv("NEXUS_HOME");
-  if (!nexusHome)
-    nexusHome = "..";
-  string nexusLauncher = string(nexusHome) + "/src/nexus-launcher";
+  // Get location of Mesos install in order to find mesos-launcher.
+  const char *mesosHome = getenv("MESOS_HOME");
+  if (!mesosHome)
+    mesosHome = "..";
+  string mesosLauncher = string(mesosHome) + "/src/mesos-launcher";
 
   // Create a name for the container
   ostringstream oss;
-  oss << "nexus.slave-" << slave->id << ".framework-" << fw->id;
+  oss << "mesos.slave-" << slave->id << ".framework-" << fw->id;
   string containerName = oss.str();
 
-  container[fw->id] = containerName;
+  infos[fw->id]->container = containerName;
   fw->executorStatus = "Container: " + containerName;
 
-  // Run lxc-execute nexus-launcher using a fork-exec (since lxc-execute
+  // Run lxc-execute mesos-launcher using a fork-exec (since lxc-execute
   // does not return until the container is finished). Note that lxc-execute
   // automatically creates the container and will delete it when finished.
   pid_t pid;
@@ -100,7 +127,7 @@ void LxcIsolationModule::startExecutor(F
 
   if (pid) {
     // In parent process
-    lxcExecutePid[fw->id] = pid;
+    infos[fw->id]->lxcExecutePid = pid;
     LOG(INFO) << "Started lxc-execute, pid = " << pid;
     int status;
   } else {
@@ -113,17 +140,17 @@ void LxcIsolationModule::startExecutor(F
       }
     }
 
-    // Set up Nexus environment variables for launcher.
-    setenv("NEXUS_FRAMEWORK_ID", lexical_cast<string>(fw->id).c_str(), 1);
-    setenv("NEXUS_EXECUTOR_URI", fw->executorInfo.uri.c_str(), 1);
-    setenv("NEXUS_USER", fw->user.c_str(), 1);
-    setenv("NEXUS_SLAVE_PID", lexical_cast<string>(slave->self()).c_str(), 1);
-    setenv("NEXUS_REDIRECT_IO", slave->local ? "1" : "0", 1);
-    setenv("NEXUS_WORK_DIRECTORY", slave->getWorkDirectory(fw->id).c_str(), 1);
+    // Set up Mesos environment variables for launcher.
+    setenv("MESOS_FRAMEWORK_ID", lexical_cast<string>(fw->id).c_str(), 1);
+    setenv("MESOS_EXECUTOR_URI", fw->executorInfo.uri.c_str(), 1);
+    setenv("MESOS_USER", fw->user.c_str(), 1);
+    setenv("MESOS_SLAVE_PID", lexical_cast<string>(slave->self()).c_str(), 1);
+    setenv("MESOS_REDIRECT_IO", slave->local ? "0" : "1", 1);
+    setenv("MESOS_WORK_DIRECTORY", slave->getWorkDirectory(fw->id).c_str(), 1);
 
     // Run lxc-execute.
     execlp("lxc-execute", "lxc-execute", "-n", containerName.c_str(),
-           nexusLauncher.c_str(), (char *) NULL);
+           mesosLauncher.c_str(), (char *) NULL);
     // If we get here, the execl call failed.
     fatalerror("Could not exec lxc-execute");
     // TODO: Exit the slave if this happens
@@ -133,12 +160,13 @@ void LxcIsolationModule::startExecutor(F
 
 void LxcIsolationModule::killExecutor(Framework* fw)
 {
-  if (container[fw->id] != "") {
-    LOG(INFO) << "Stopping container " << container[fw->id];
-    int ret = shell("lxc-stop -n %s", container[fw->id].c_str());
+  string container = infos[fw->id]->container;
+  if (container != "") {
+    LOG(INFO) << "Stopping container " << container;
+    int ret = shell("lxc-stop -n %s", container.c_str());
     if (ret != 0)
       LOG(ERROR) << "lxc-stop returned " << ret;
-    container[fw->id] = "";
+    infos[fw->id]->container = "";
     fw->executorStatus = "No executor running";
   }
 }
@@ -146,28 +174,45 @@ void LxcIsolationModule::killExecutor(Fr
 
 void LxcIsolationModule::resourcesChanged(Framework* fw)
 {
-  if (container[fw->id] != "") {
-    // For now, just try setting the CPUs and mem right away.
-    // A slightly smarter thing might be to only update them periodically.
-    int ret;
-    
-    int32_t cpuShares = max(1024 * fw->resources.cpus, 10);
-    LOG(INFO) << "Setting CPU shares for " << fw->id << " to " << cpuShares;
-    ret = shell("lxc-cgroup -n %s cpu.shares %d",
-                container[fw->id].c_str(), cpuShares);
-    if (ret != 0)
-      LOG(ERROR) << "lxc-cgroup returned " << ret;
+  if (infos[fw->id]->container != "") {
+    // For now, just try setting the CPUs and memory right away, and kill the
+    // framework if this fails.
+    // A smarter thing to do might be to only update them periodically in a
+    // separate thread, and to give frameworks some time to scale down their
+    // memory usage.
+
+    int32_t cpuShares = max(CPU_SHARES_PER_CPU * fw->resources.cpus,
+                            MIN_CPU_SHARES);
+    if (!setResourceLimit(fw, "cpu.shares", cpuShares)) {
+      slave->removeExecutor(fw->id, true);
+      return;
+    }
 
-    int64_t rssLimit = max(fw->resources.mem, 128 * Megabyte);
-    LOG(INFO) << "Setting RSS limit for " << fw->id << " to " << rssLimit;
-    ret = shell("lxc-cgroup -n %s memory.limit_in_bytes %lld",
-                container[fw->id].c_str(), rssLimit);
-    if (ret != 0)
-      LOG(ERROR) << "lxc-cgroup returned " << ret;
-    
-    // TODO: Decreasing the RSS limit will fail if the current RSS is too
-    // large and memory can't be swapped out. In that case, we should
-    // either freeze the container before changing RSS, or just kill it.
+    int64_t rssLimit = max(fw->resources.mem, MIN_RSS);
+    if (!setResourceLimit(fw, "memory.limit_in_bytes", rssLimit)) {
+      slave->removeExecutor(fw->id, true);
+      return;
+    }
+  }
+}
+
+
+bool LxcIsolationModule::setResourceLimit(Framework* fw,
+                                          const string& property,
+                                          int64_t value)
+{
+  LOG(INFO) << "Setting " << property << " for framework " << fw->id
+            << " to " << value;
+  int ret = shell("lxc-cgroup -n %s %s %lld",
+                  infos[fw->id]->container.c_str(),
+                  property.c_str(),
+                  value);
+  if (ret != 0) {
+    LOG(ERROR) << "Failed to set " << property << " for framework " << fw->id
+               << ": lxc-cgroup returned " << ret;
+    return false;
+  } else {
+    return true;
   }
 }
 
@@ -207,10 +252,10 @@ void LxcIsolationModule::Reaper::operato
       pid_t pid;
       int status;
       if ((pid = waitpid((pid_t) -1, &status, WNOHANG)) > 0) {
-        foreachpair (FrameworkID fid, pid_t& fwPid, module->lxcExecutePid) {
-          if (fwPid == pid) {
-            module->container[fid] = "";
-            module->lxcExecutePid[fid] = -1;
+        foreachpair (FrameworkID fid, FrameworkInfo* info, module->infos) {
+          if (info->lxcExecutePid == pid) {
+            info->container = "";
+            info->lxcExecutePid = -1;
             LOG(INFO) << "Telling slave of lost framework " << fid;
             // TODO(benh): This is broken if/when libprocess is parallel!
             module->slave->executorExited(fid, status);

Modified: incubator/mesos/trunk/src/lxc_isolation_module.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/lxc_isolation_module.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/lxc_isolation_module.hpp (original)
+++ incubator/mesos/trunk/src/lxc_isolation_module.hpp Sun Jun  5 05:49:41 2011
@@ -9,7 +9,7 @@
 #include "messages.hpp"
 #include "slave.hpp"
 
-namespace nexus { namespace internal { namespace slave {
+namespace mesos { namespace internal { namespace slave {
 
 using std::string;
 using boost::unordered_map;
@@ -28,7 +28,7 @@ public:
   };
 
   // Extra shutdown message for reaper
-  enum { SHUTDOWN_REAPER = NEXUS_MESSAGES };
+  enum { SHUTDOWN_REAPER = MESOS_MESSAGES };
 
   // Per-framework information object maintained in info hashmap
   struct FrameworkInfo {

Modified: incubator/mesos/trunk/src/master.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/master.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/master.cpp (original)
+++ incubator/mesos/trunk/src/master.cpp Sun Jun  5 05:49:41 2011
@@ -24,9 +24,9 @@ using boost::lexical_cast;
 using boost::unordered_map;
 using boost::unordered_set;
 
-using namespace nexus;
-using namespace nexus::internal;
-using namespace nexus::internal::master;
+using namespace mesos;
+using namespace mesos::internal;
+using namespace mesos::internal::master;
 
 
 namespace {
@@ -268,7 +268,7 @@ void Master::updateFrameworkTasks(Task *
 
 void Master::operator () ()
 {
-  LOG(INFO) << "Master started at nexus://" << self();
+  LOG(INFO) << "Master started at mesos://" << self();
 
   // Don't do anything until we get an identifier.
   while (true) {

Modified: incubator/mesos/trunk/src/master.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/master.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/master.hpp (original)
+++ incubator/mesos/trunk/src/master.hpp Sun Jun  5 05:49:41 2011
@@ -33,7 +33,7 @@
 #include "task.hpp"
 
 
-namespace nexus { namespace internal { namespace master {
+namespace mesos { namespace internal { namespace master {
 
 using std::make_pair;
 using std::map;
@@ -45,8 +45,8 @@ using std::vector;
 using boost::unordered_map;
 using boost::unordered_set;
 
-using namespace nexus;
-using namespace nexus::internal;
+using namespace mesos;
+using namespace mesos::internal;
 
 
 // Maximum number of slot offers to have outstanding for each framework.

Modified: incubator/mesos/trunk/src/master_detector.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/master_detector.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/master_main.cpp (original)
+++ incubator/mesos/trunk/src/master_main.cpp Sun Jun  5 05:49:41 2011
@@ -11,7 +11,7 @@ using std::endl;
 using boost::lexical_cast;
 using boost::bad_lexical_cast;
 
-using namespace nexus::internal::master;
+using namespace mesos::internal::master;
 
 
 void usage(const char* progName, const Configurator& conf)
@@ -32,7 +32,7 @@ int main(int argc, char **argv)
   Configurator conf;
   conf.addOption<string>("url", 'u', "URL used for leader election");
   conf.addOption<int>("port", 'p', "Port to listen on", 50010);
-#ifdef NEXUS_WEBUI
+#ifdef MESOS_WEBUI
   conf.addOption<int>("webui_port", 'w', "Web UI port", 8080);
 #endif
   Logging::registerOptions(&conf);
@@ -59,7 +59,7 @@ int main(int argc, char **argv)
   string url = params.get("url", "");
 
   LOG(INFO) << "Build: " << BUILD_DATE << " by " << BUILD_USER;
-  LOG(INFO) << "Starting Nexus master";
+  LOG(INFO) << "Starting Mesos master";
 
   if (chdir(dirname(argv[0])) != 0)
     fatalerror("Could not chdir into %s", dirname(argv[0]));
@@ -70,7 +70,7 @@ int main(int argc, char **argv)
   bool quiet = Logging::isQuiet(params);
   MasterDetector *detector = MasterDetector::create(url, pid, true, quiet);
 
-#ifdef NEXUS_WEBUI
+#ifdef MESOS_WEBUI
   startMasterWebUI(pid, (char*) params["webui_port"].c_str());
 #endif
   

Modified: incubator/mesos/trunk/src/master_state.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/master_state.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/master_state.hpp (original)
+++ incubator/mesos/trunk/src/master_state.hpp Sun Jun  5 05:49:41 2011
@@ -9,7 +9,7 @@
 #include "foreach.hpp"
 #include "messages.hpp"
 
-namespace nexus { namespace internal { namespace master { namespace state {
+namespace mesos { namespace internal { namespace master { namespace state {
 
 struct SlaveResources
 {  

Modified: incubator/mesos/trunk/src/master_webui.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/master_webui.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/master_webui.cpp (original)
+++ incubator/mesos/trunk/src/master_webui.cpp Sun Jun  5 05:49:41 2011
@@ -3,7 +3,7 @@
 #include "master_webui.hpp"
 #include "master_state.hpp"
 
-#ifdef NEXUS_WEBUI
+#ifdef MESOS_WEBUI
 
 #include <pthread.h>
 #include <Python.h>
@@ -16,7 +16,7 @@ PID master;
 
 }
 
-namespace nexus { namespace internal { namespace master {
+namespace mesos { namespace internal { namespace master {
 
 
 void *runMasterWebUI(void* webuiPort)
@@ -80,6 +80,6 @@ MasterState *get_master()
 
 } /* namespace state { */
 
-}}} /* namespace nexus { namespace internal { namespace master { */
+}}} /* namespace mesos { namespace internal { namespace master { */
 
-#endif /* NEXUS_WEBUI */
+#endif /* MESOS_WEBUI */

Modified: incubator/mesos/trunk/src/master_webui.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/master_webui.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/master_webui.hpp (original)
+++ incubator/mesos/trunk/src/master_webui.hpp Sun Jun  5 05:49:41 2011
@@ -6,14 +6,14 @@
 #include "config.hpp"
 #include "master.hpp"
 
-#ifdef NEXUS_WEBUI
+#ifdef MESOS_WEBUI
 
-namespace nexus { namespace internal { namespace master {
+namespace mesos { namespace internal { namespace master {
 
 void startMasterWebUI(const PID &master, char* webuiPort);
 
 }}} /* namespace */
 
-#endif /* NEXUS_WEBUI */
+#endif /* MESOS_WEBUI */
 
 #endif /* MASTER_WEBUI_HPP */

Modified: incubator/mesos/trunk/src/memhog.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/memhog.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/memhog.cpp (original)
+++ incubator/mesos/trunk/src/memhog.cpp Sun Jun  5 05:49:41 2011
@@ -1,4 +1,4 @@
-#include <nexus_sched.hpp>
+#include <mesos_sched.hpp>
 
 #include <cstdlib>
 #include <iostream>
@@ -9,7 +9,7 @@
 #include "foreach.hpp"
 
 using namespace std;
-using namespace nexus;
+using namespace mesos;
 
 using boost::lexical_cast;
 
@@ -100,7 +100,7 @@ int main(int argc, char ** argv) {
                     lexical_cast<int>(argv[4]),
                     lexical_cast<int64_t>(argv[5]) * 1024 * 1024,
                     lexical_cast<int64_t>(argv[6]) * 1024 * 1024);
-  NexusSchedulerDriver driver(&sched, argv[1]);
+  MesosSchedulerDriver driver(&sched, argv[1]);
   driver.run();
   return 0;
 }

Modified: incubator/mesos/trunk/src/memhog_executor.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/memhog_executor.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/memhog_executor.cpp (original)
+++ incubator/mesos/trunk/src/memhog_executor.cpp Sun Jun  5 05:49:41 2011
@@ -1,13 +1,13 @@
 #include <time.h>
 
-#include <nexus_exec.hpp>
+#include <mesos_exec.hpp>
 
 #include <cstdlib>
 #include <iostream>
 #include <sstream>
 
 using namespace std;
-using namespace nexus;
+using namespace mesos;
 
 
 class MemHogExecutor;
@@ -103,7 +103,7 @@ void* runTask(void* threadArg)
 
 int main(int argc, char** argv) {
   MemHogExecutor exec;
-  NexusExecutorDriver driver(&exec);
+  MesosExecutorDriver driver(&exec);
   driver.run();
   return 0;
 }
--- incubator/mesos/trunk/src/launcher.cpp (original)
+++ incubator/mesos/trunk/src/launcher.cpp Sun Jun  5 05:49:41 2011
@@ -27,9 +27,9 @@ using std::vector;
 
 using boost::lexical_cast;
 
-using namespace nexus;
-using namespace nexus::internal;
-using namespace nexus::internal::launcher;
+using namespace mesos;
+using namespace mesos::internal;
+using namespace mesos::internal::launcher;
 
 
 ExecutorLauncher::ExecutorLauncher(FrameworkID _frameworkId,
@@ -192,9 +192,9 @@ void ExecutorLauncher::setupEnvironment(
     }
   }
 
-  // Set Nexus environment variables to pass slave ID, framework ID, etc.
-  setenv("NEXUS_SLAVE_PID", slavePid.c_str(), true);
-  setenv("NEXUS_FRAMEWORK_ID", frameworkId.c_str(), true);
+  // Set Mesos environment variables to pass slave ID, framework ID, etc.
+  setenv("MESOS_SLAVE_PID", slavePid.c_str(), true);
+  setenv("MESOS_FRAMEWORK_ID", frameworkId.c_str(), true);
   
   // Set LIBPROCESS_PORT so that we bind to a random free port.
   setenv("LIBPROCESS_PORT", "0", true);

Modified: incubator/mesos/trunk/src/launcher.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/launcher.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/master_detector.cpp (original)
+++ incubator/mesos/trunk/src/master_detector.cpp Sun Jun  5 05:49:41 2011
@@ -19,8 +19,8 @@
 #include "url_processor.hpp"
 #include "zookeeper.hpp"
 
-using namespace nexus;
-using namespace nexus::internal;
+using namespace mesos;
+using namespace mesos::internal;
 
 using namespace std;
 
@@ -138,8 +138,8 @@ MasterDetector * MasterDetector::create(
       break;
     }
 
-    // Nexus URL or libprocess pid.
-    case UrlProcessor::NEXUS:
+    // Mesos URL or libprocess pid.
+    case UrlProcessor::MESOS:
     case UrlProcessor::UNKNOWN: {
       if (contend) {
 	// TODO(benh): Wierdnesses like this makes it seem like there

Modified: incubator/mesos/trunk/src/master_detector.hpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/master_detector.hpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================
--- incubator/mesos/trunk/src/master_detector.hpp (original)
+++ incubator/mesos/trunk/src/master_detector.hpp Sun Jun  5 05:49:41 2011
@@ -8,7 +8,7 @@
 #include <cstdlib>
 
 
-namespace nexus { namespace internal {
+namespace mesos { namespace internal {
 
 /**
  * Implements functionality for:
@@ -26,7 +26,7 @@ public:
    * master detector sends messages to the specified pid when a new
    * master is elected, a master is lost, etc.
    *
    * @param url string possibly containing zoo://, zoofile://, nexus://
    * @param pid libprocess pid to both receive our messages and be
    * used if we should contend
    * @param contend true if should contend to be master
@@ -100,7 +100,7 @@ private:
   PID master;
 };
 
-}} /* namespace nexus { namespace internal { */
+}} /* namespace mesos { namespace internal { */
 
 #endif /* __MASTER_DETECTOR_HPP__ */
 
@@ -26,7 +26,7 @@ public:
    * master is elected, a master is lost, etc.
    *
-   * @param url string possibly containing zoo://, zoofile://, nexus://
+   * @param url string possibly containing zoo://, zoofile://, mesos://
    * @param pid libprocess pid to both receive our messages and be
    * used if we should contend

Modified: incubator/mesos/trunk/src/master_main.cpp
URL: http://svn.apache.org/viewvc/incubator/mesos/trunk/src/master_main.cpp?rev=1131909&r1=1131908&r2=1131909&view=diff
==============================================================================